@@ -3,4 +3,4 @@
 """
 from mytextgrid.core.textgrid import create_textgrid
 from mytextgrid.core.textgrid import TextGrid
-from mytextgrid.io.parser.full_text_format import read_from_file
+from mytextgrid.io.textgrid_in import read_from_file
